@@ -102,8 +102,9 @@ ars_GetEntryBLOB
 ars_CreateActiveLink ars_CreateAdminExtension
 ars_GetControlStructFields ars_GetVUI
 ars_GetListContainer ars_GetContainer ars_SetServerPort
+ars_SetLogging
 $ars_errstr %ARServerStats %ars_errhash
-ars_decodeStatusHistory ars_APIVersion
+ars_decodeStatusHistory ars_APIVersion ars_encodeStatusHistory
 );
 
 $ARS::VERSION   = '1.84';
@@ -206,7 +207,8 @@ tie $ARS::ars_errstr, ARS::ERRORSTR;
  'FILTER_FIELDS_FLTAPI', 70,
  'ESCL_FIELDS_SQL', 71,
  'ESCL_FIELDS_PROCESS', 72,
- 'ESCL_FIELDS_FLTAPI', 73
+ 'ESCL_FIELDS_FLTAPI', 73,
+ 'WRITE_RESTRICTED_READ', 74
 );
 
 
@@ -443,6 +445,17 @@ sub ars_ExpandCharMenu {
 	return ars_ExpandCharMenu2(@_);
 }
 
+# encodes status history from the same format
+# as returned by ars_decodeStatusHistory()
+
+sub ars_encodeStatusHistory {
+	my @sh = ();
+	while(my $hr = shift) {
+		push @sh, $hr->{USER} ? "$hr->{TIME}\cD$hr->{USER}" : "";
+	}
+	join "\cC", @sh;
+}
+
 # As of ARS4.0, these routines (which call ARInitialization and ARTermination)
 # need to pass a control struct. this means that we now must move them into
 # ars_Login and ars_Logoff in order to have access to that control struct.
